#ifndef _IOCTLCMD_H
#define _IOCTLCMD_H


/* A simple version constant strings. Used everytime the 
 * TraceHook ver information is required.
 */
#define TRACEHOOK_VERSION "v0.0.2"

/* The actual name of the TraceHook's device driver
 */
const CHAR DriverFileName[] = "TraceHook.sys";

/* The HDD pathes of where the malware process dumps are going
 * to be stored in.
 */
const CHAR UserDumpPath[]   = "C:\\dump";

/* The symbolic filenames used by the user-mode client application
 * to communicate with the kernel module
 */
const WCHAR DriverName[]    = L"\\Device\\TraceHook";
const WCHAR DosDeviceName[] = L"\\DosDevices\\TraceHook";


/* The input structure passed to the driver as the SetDumpMode IOCTL operation
 */
enum DumpModes
{
  FullMemoryDump,
  MiniDump
};

typedef struct _DumpMode
{
  /* The user can choose out of two dump types, each implemented in a separate way
   */
  enum DumpModes DumpType;

  /* The below data is only used in case MiniDump is chosen
   */
  DWORD dwTraceHookPid;
  HANDLE hThreadApc;
  PIO_APC_ROUTINE ApcRoutine;
} DumpMode;


/* 
 * The IOCTL message definitions (both constant identifiers and handler functions
 */
#define IOCTL_QUERY_VERSION \
CTL_CODE(FILE_DEVICE_UNKNOWN, 0x880, METHOD_BUFFERED, FILE_READ_DATA)
#define IOCTL_FINISH \
CTL_CODE(FILE_DEVICE_UNKNOWN, 0x881, METHOD_BUFFERED , FILE_READ_DATA)

#define IOCTL_ADD_PROCESS \
CTL_CODE(FILE_DEVICE_UNKNOWN, 0x882, METHOD_NEITHER , FILE_READ_DATA)
#define IOCTL_REMOVE_PROCESS \
CTL_CODE(FILE_DEVICE_UNKNOWN, 0x883, METHOD_NEITHER , FILE_READ_DATA)
#define IOCTL_SET_DUMP_PATH \
CTL_CODE(FILE_DEVICE_UNKNOWN, 0x884, METHOD_NEITHER , FILE_READ_DATA)
#define IOCTL_SET_DUMP_MODE \
CTL_CODE(FILE_DEVICE_UNKNOWN, 0x885, METHOD_NEITHER , FILE_READ_DATA)


NTSTATUS
HandleQueryVersion(
	PVOID,
	PVOID,
	ULONG,
	ULONG
);

NTSTATUS
HandleFinish(
	PVOID,
	PVOID,
	ULONG,
	ULONG
);

NTSTATUS
HandleAddProcess(
	PVOID,
	PVOID,
	ULONG,
	ULONG
);

NTSTATUS
HandleRemoveProcess(
	PVOID,
	PVOID,
	ULONG,
	ULONG
);

NTSTATUS
HandleSetDumpPath(
	PVOID,
	PVOID,
	ULONG,
	ULONG
);

NTSTATUS
HandleSetDumpMode(
	PVOID,
	PVOID,
	ULONG,
	ULONG
);

#endif


